==> pdf-model-arlington-1.23.7-sources.jar: org/verapdf/model/alayer/AAnnot3D.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
public interface AAnnot3D extends AObject {
	












	public Boolean getcontains3DA();

	public Boolean getentry3DAHasTypeDictionary();

	public Boolean getcontains3DB();

	public Boolean getentry3DBHasTypeRectangle();

	public Boolean getcontains3DD();

	public Boolean getisentry3DDIndirect();

	public Boolean getentry3DDHasTypeDictionary();

	public Boolean getentry3DDHasTypeStream();

	public Boolean getcontains3DI();

	public Boolean getentry3DIHasTypeBoolean();

	public Boolean getcontains3DU();

	public Boolean getentry3DUHasTypeDictionary();

	public Boolean getcontains3DV();

	public Boolean getentry3DVHasTypeDictionary();

	public Boolean getentry3DVHasTypeInteger();

	public Boolean getentry3DVHasTypeName();

	public Boolean getentry3DVHasTypeString();

	public Boolean getcontainsAF();

	public Boolean getAFHasTypeArray();

	public Boolean getAFHasTypeDictionary();

	public Boolean getcontainsAP();

	public Boolean getAPHasTypeDictionary();

	public Boolean getcontainsAS();

	public Boolean getASHasTypeName();

	public Boolean getcontainsBM();

	public Boolean getBMHasTypeName();

	public String getBMNameValue();

	public Boolean getcontainsBorder();

	public Boolean getBorderHasTypeArray();

	public Boolean getcontainsC();

	public Boolean getCHasTypeArray();

	public Boolean getcontainsCA();

	public Boolean getCAHasTypeNumber();

	public Double getCANumberValue();

	public Boolean getcontainsContents();

	public Boolean getContentsHasTypeStringText();

	public Boolean getcontainsF();

	public Boolean getFHasTypeBitmask();

	public Long getFBitmaskValue();

	public Boolean getcontainsGEO();

	public Boolean getGEOHasTypeDictionary();

	public Boolean getcontainsLang();

	public Boolean getLangHasTypeStringText();

	public Boolean getcontainsM();

	public Boolean getMHasTypeDate();

	public Boolean getMHasTypeStringText();

	public Boolean getcontainsNM();

	public Boolean getNMHasTypeStringText();

	public Boolean getcontainsOC();

	public Boolean getOCHasTypeDictionary();

	public Boolean getcontainsP();

	public Boolean getisPIndirect();

	public Boolean getPHasTypeDictionary();

	public Boolean getcontainsRect();

	public Boolean getRectHasTypeRectangle();

	public Double getRectRectHeight();

	public Double getRectRectWidth();

	public Boolean getcontainsStructParent();

	public Boolean getStructParentHasTypeInteger();

	public Boolean getcontainsSubtype();

	public Boolean getSubtypeHasTypeName();

	public String getSubtypeNameValue();

	public Boolean getcontainsType();

	public Boolean getTypeHasTypeName();

	public String getTypeNameValue();

	public Boolean getcontainsca();

	public Boolean getcaHasTypeNumber();

	public Double getcaNumberValue();

	public Boolean getcontainsAPNAny();

	public Boolean getcontainsAPRAny();

	public Boolean getcontainsAPDAny();
}

==> pdf-model-arlington-1.25.14-sources.jar: org/verapdf/model/alayer/AAnnot3D.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AAnnot3D extends AObject {
	












	/**
	*/
	public Boolean getcontains3DA();

	/**
	*/
	public Boolean getentry3DAHasTypeDictionary();

	/**
	*/
	public Boolean getcontains3DB();

	/**
	*/
	public Boolean getentry3DBHasTypeRectangle();

	/**
	*/
	public Boolean getcontains3DD();

	/**
	*/
	public Boolean getisentry3DDIndirect();

	/**
	*/
	public Boolean getentry3DDHasTypeDictionary();

	/**
	*/
	public Boolean getentry3DDHasTypeStream();

	/**
	*/
	public Boolean getcontains3DI();

	/**
	*/
	public Boolean getentry3DIHasTypeBoolean();

	/**
	*/
	public Boolean getcontains3DU();

	/**
	*/
	public Boolean getentry3DUHasTypeDictionary();

	/**
	*/
	public Boolean getcontains3DV();

	/**
	*/
	public Boolean getentry3DVHasTypeDictionary();

	/**
	*/
	public Boolean getentry3DVHasTypeInteger();

	/**
	*/
	public Boolean getentry3DVHasTypeName();

	/**
	*/
	public Boolean getentry3DVHasTypeString();

	/**
	*/
	public Boolean getcontainsAF();

	/**
	*/
	public Boolean getAFHasTypeArray();

	/**
	*/
	public Boolean getAFHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsAP();

	/**
	*/
	public Boolean getAPHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsAS();

	/**
	*/
	public Boolean getASHasTypeName();

	/**
	*/
	public Boolean getcontainsBM();

	/**
	*/
	public Boolean getBMHasTypeName();

	/**
	*/
	public String getBMNameValue();

	/**
	*/
	public Boolean getcontainsBorder();

	/**
	*/
	public Boolean getBorderHasTypeArray();

	/**
	*/
	public Boolean getcontainsC();

	/**
	*/
	public Boolean getCHasTypeArray();

	/**
	*/
	public Boolean getcontainsCA();

	/**
	*/
	public Boolean getCAHasTypeNumber();

	/**
	*/
	public Double getCANumberValue();

	/**
	*/
	public Boolean getcontainsContents();

	/**
	*/
	public Boolean getContentsHasTypeStringText();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public Boolean getFHasTypeBitmask();

	/**
	*/
	public Long getFBitmaskValue();

	/**
	*/
	public Boolean getcontainsGEO();

	/**
	*/
	public Boolean getGEOHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsLang();

	/**
	*/
	public Boolean getLangHasTypeStringText();

	/**
	*/
	public Boolean getcontainsM();

	/**
	*/
	public Boolean getMHasTypeDate();

	/**
	*/
	public Boolean getMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsNM();

	/**
	*/
	public Boolean getNMHasTypeStringText();

	/**
	*/
	public Boolean getcontainsOC();

	/**
	*/
	public Boolean getOCHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public Boolean getisPIndirect();

	/**
	*/
	public Boolean getPHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsRect();

	/**
	*/
	public Boolean getRectHasTypeRectangle();

	/**
	*/
	public Double getRectRectHeight();

	/**
	*/
	public Double getRectRectWidth();

	/**
	*/
	public Boolean getcontainsStructParent();

	/**
	*/
	public Boolean getStructParentHasTypeInteger();

	/**
	*/
	public Boolean getcontainsSubtype();

	/**
	*/
	public Boolean getSubtypeHasTypeName();

	/**
	*/
	public String getSubtypeNameValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsca();

	/**
	*/
	public Boolean getcaHasTypeNumber();

	/**
	*/
	public Double getcaNumberValue();

	/**
	*/
	public Boolean getAPNHasTypeDictionary();

	/**
	*/
	public Boolean getAPRHasTypeDictionary();

	/**
	*/
	public Boolean getAPDHasTypeDictionary();

	/**
	*/
	public Boolean gethasExtensionADBE_Extn3();
}
